Code Reviews with Gerrit
========================

Zun uses the `Gerrit`_ tool to review proposed code changes. The review site
is https://review.openstack.org.

Gerrit is a complete replacement for Github pull requests. `All Github pull
requests to the Zun repository will be ignored`.

See `Gerrit Workflow Quick Reference`_ for information about how to get
started using Gerrit. See `Development Workflow`_ for more detailed
documentation on how to work with Gerrit.

.. _Gerrit: https://bugs.chromium.org/p/gerrit/
.. _Development Workflow: https://docs.openstack.org/infra/manual/developers.html#development-workflow
.. _Gerrit Workflow Quick Reference: https://docs.openstack.org/infra/manual/developers.html#development-workflow
